<div id="navbar" class="{{ theme_navbar_class }} navbar-default {% if theme_navbar_fixed_top|tobool -%} navbar-fixed-top{%- endif -%}">
  <div class="container">
    <div class="navbar-header">
      <!-- .btn-navbar is used as the toggle for collapsed navbar content -->
      <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".nav-collapse">
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
      </button>
      <a class="navbar-brand" href="{{ pathto(master_doc) }}">
        {%- block sidebarlogo %}
          {%- if logo %}<img src="{{ pathto('_static/' + logo, 1) }}">{%- endif %}
        {%- endblock %}
        {% if theme_navbar_title -%}{{ theme_navbar_title|e }}{%- else -%}{{ project|e }}{%- endif -%}
      </a>
      <span class="navbar-text navbar-version pull-left"><b>{{ version|e }}</b></span>
    </div>

      <div class="collapse navbar-collapse nav-collapse">
        <ul class="nav navbar-nav">
          {% if theme_navbar_links %}
            {%- for link in theme_navbar_links %}
              <li><a href="{{ pathto(*link[1:]) }}">{{ link[0] }}</a></li>
            {%- endfor %}
          {% endif %}
          {% block navbarextra %}
          {% endblock %}
          {% if theme_source_link_position == "nav" %}
            <li class="hidden-sm">{% include "sourcelink.html" %}</li>
          {% endif %}
        </ul>

        {% block navbarsearch %}
          {% include "navbarsearchbox.html" %}
        {% endblock %}
        {% if theme_navbar_sidebarrel %}
          {% block sidebarrel %}
            <ul class='nav navbar-nav navbar-right'>
                {% include "relations.html" %}
            </ul>
          {% endblock %}
        {% endif %}
      </div>
  </div>
</div>
